package com.chemaxon.checkers.example.tests;

import chemaxon.struc.MolAtom;
import chemaxon.struc.Molecule;

import com.chemaxon.checkers.example.MyFirstStructureChecker;

import junit.framework.TestCase;

/**
 * This is a JUNIT test class for {@link MyFirstStructureChecker}
 * @see MyFirstStructureChecker
 */
public class MyFirstStructureCheckerTest extends TestCase {
	/**
	 * This method tests the checking mechanism against molecules with bigger or smaller mass
	 * than 500.
	 */
	public void testCheck() {
		//Initiate the checker instance. Trough this instance will be the implementation tested/
		MyFirstStructureChecker checker = new MyFirstStructureChecker();
		//It is obvious that this initialization part should be in the setUp() method
		//but didn't want to scare away developers not too familiar with JUNIT framework
		
		//Initiate a molecule instance with one carbon atom
		Molecule small = new Molecule();
		small.add(new MolAtom(6));
		
		/*
		 * Checker isn't allowed to sign an error in this case, 
		 * so is not allowed to return a not null value.
		 */
		assertNull(checker.check(small));
		
		//Initiate a molecule with 150 uranium atoms
		Molecule big = new Molecule();
		for (int i=0;i<150;++i) {
			big.add(new MolAtom(92));
		}
		
		/*
		 * Checker has to sign error in this case, so null return value 
		 * means error in the implementation.
		 */
		assertNotNull(checker.check(big));
	}
}
